<?php
function filter_module_safe_url($url){
    $url = trim($url);
    $url = mb_strtolower($url);
    $url = preg_replace("/\.\w{2,4}$/", '', $url);
    $url = str_replace(' ', '-', html_entity_decode($url, ENT_QUOTES));
    $url = preg_replace('#[^\w\-_/]#iuU', '-', str_replace('/', '/', $url));
    $url = preg_replace(array('#/{2,}#iu', '#-{2,}#'), array('/', '-'), $url);
    return trim($url, '-');
}

/*
#######################
# 	SETUP CUBECART    #
#######################
*/

$include_cc_root = __DIR__ . "/../../../../";

/*
#######################
# 	SETUP CUBECART    #
#######################
*/

if (!isset($_SERVER['SERVER_PORT'])) {
	$_SERVER['SERVER_PORT'] = getenv('SERVER_PORT');
}

if (!isset($_SERVER['SERVER_NAME'])) {
	$_SERVER['SERVER_NAME'] = getenv('SERVER_NAME');
}



require_once($include_cc_root . "ini.inc.php");
require_once($include_cc_root . 'includes/global.inc.php');
define('ADMIN_CP', false);
require_once($include_cc_root . 'includes/functions.inc.php');

// Initialize Cache
$GLOBALS['cache'] = Cache::getInstance();
// Initialise Database class, and fetch default configuration
$GLOBALS['db'] = Database::getInstance($glob);
// Initialise Config class
$GLOBALS['config'] = Config::getInstance($glob);
$GLOBALS['config']->merge('config', '', $config_default);
// Initialize debug
$GLOBALS['debug'] = Debug::getInstance();

//Initialize Smarty
$GLOBALS['smarty'] = new Smarty();
$GLOBALS['smarty']->muteExpectedErrors();
$GLOBALS['smarty']->error_reporting = E_ALL & ~E_NOTICE & ~E_WARNING;
$GLOBALS['smarty']->compile_dir  = CC_SKIN_CACHE_DIR;
$GLOBALS['smarty']->config_dir   = CC_SKIN_CACHE_DIR;
$GLOBALS['smarty']->cache_dir    = CC_SKIN_CACHE_DIR;
$GLOBALS['smarty']->debugging = false;
//Initialize language
$GLOBALS['language'] = Language::getInstance();
//Initialize hooks
$GLOBALS['hooks'] = HookLoader::getInstance();

//Initialize SEO
$GLOBALS['seo'] = SEO::getInstance();

// Time limit
set_time_limit(600); // 10 mins


// Everything needs a value...
$sql = "
		SELECT
			id,
			filter_name
		FROM
			" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_type
		WHERE
			seo_path IS NULL
			or
			seo_path = ''
	";
$types = $GLOBALS['db']->query($sql, false, 0, false);

if(isset($types) && is_array($types) && !empty($types)){
	foreach($types as $type){
		$GLOBALS['db']->update('CubeCart_product_filter_type', array('seo_path' => filter_module_safe_url($type['filter_name'])), array('id' => $type['id']));
	}
}

// Everything needs a value...
$sql = "
		SELECT
			id,
			value_name
		FROM
			" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_values
		WHERE
			seo_path IS NULL
			or
			seo_path = ''
	";
$values = $GLOBALS['db']->query($sql, false, 0, false);

if(isset($values) && is_array($values) && !empty($values)){
	foreach($values as $type){
		$GLOBALS['db']->update('CubeCart_product_filter_values', array('seo_path' => filter_module_safe_url($type['value_name'])), array('id' => $type['id']));
	}
}

// Cleanup existing SEO paths
$GLOBALS['db']->delete('CubeCart_seo_urls', array('custom_filter_record' => 1));
$cats = $GLOBALS['db']->select('CubeCart_category', 'cat_id', array('status' => '1'), array('cat_id' => 'ASC'), false, false, false);

if(isset($cats) && is_array($cats) && !empty($cats)){
	foreach($cats as $cat){

		$cat_seo_path = $GLOBALS['seo']->getdbPath('cat', $cat['cat_id']);

		$sql = "
				SELECT
					v.type_id,
					fa.value_id,
					t.filter_name,
					t.seo_path as 'type_seo_path',
					v.value_name,
					v.seo_path as 'value_seo_path',
					t.is_price_filter,
					t.type_sort_order,
					v.value_sort_order,
					v.price_filter_min,
					v.price_filter_max,
					t.seo_meta_title as 'type_seo_meta_title',
					t.seo_meta_description as 'type_seo_meta_description',
					t.seo_meta_keywords as 'type_seo_meta_keywords',
					v.seo_meta_title as 'value_seo_meta_title',
					v.seo_meta_description as 'value_seo_meta_description',
					v.seo_meta_keywords as 'value_seo_meta_keywords'

				FROM
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_assign fa
				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_category_index pids
						ON
							fa.product_id = pids.product_id
							AND
							pids.cat_id = " . $cat['cat_id'] . "
				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_values v
						ON
							fa.value_id = v.id
							AND
							v.seo_path IS NOT NULL
							AND
							v.seo_path != ''
							AND
							v.enabled = 1
				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_type t
						ON
							v.type_id = t.id
							AND
							t.is_price_filter = 0
							AND
							t.seo_path  IS NOT NULL
							AND
							t.seo_path != ''
							AND
							t.enabled = 1
				WHERE
					fa.enabled = 1
				GROUP BY
					v.type_id,
					fa.value_id,
					t.filter_name,
					v.value_name
			";

		$query = $GLOBALS['db']->query($sql, false, 0, false);

		if(isset($query) && is_array($query) && !empty($query)){
			foreach($query as $found_filter){

				$custom_filter_list_items = "";

				// What is our array?
				$this_filter = array(
					$found_filter['filter_name'] => array(
						$found_filter['value_id']
					)
				);

				// Ensure our array is standard
				// Sort array by keys first....
				ksort($this_filter);

				// Then for each child array, sort by value
				foreach($this_filter as $key => $val){

					$custom_filter_list_items .= "<li><b>" . $key . "</b> : " . $found_filter['value_name'] . "</li>";

					asort($val);
					// Remove the original key & values
					unset($this_filter[$key]);
					// Then replace them with the newly sorted array
					$this_filter[$key] = $val;
				}

				$serialized = serialize($this_filter);
				$hash = md5($cat['cat_id'] . $serialized);
				$complete_array = serialize(array(
					'filter_conditions'	=>	$this_filter
				));

				// Build our new path
				$raw_path = $cat_seo_path . " " . $found_filter['type_seo_path'] . " " . $found_filter['value_seo_path'];
				$path = filter_module_safe_url($raw_path);
				$url = $path.$GLOBALS['seo']->getExtension();

				$seo_meta_title = $found_filter['type_seo_meta_title'] . " " . $found_filter['value_seo_meta_title'];
				$seo_meta_description = $found_filter['type_seo_meta_description'] . " " . $found_filter['value_seo_meta_description'];
				$seo_meta_keywords = $found_filter['type_seo_meta_keywords'] . " " . $found_filter['value_seo_meta_keywords'];


				$GLOBALS['db']->insert('CubeCart_seo_urls',
					array(
						'path'									=>	$path,
						'type'									=>	'cat',
						'item_id'								=>	$cat['cat_id'],
						'custom'								=>	1,
						'custom_filter_parameters'				=>	$complete_array,
						'custom_filter_hash'					=>	$hash,
						'custom_filter_url'						=>	$url,
						'custom_filter_record'					=> 	1,
						'custom_filter_list_items'  			=>  $custom_filter_list_items,
						'custom_filter_seo_meta_title'			=>	$seo_meta_title,
						'custom_filter_seo_meta_description'	=>	$seo_meta_description,
						'custom_filter_seo_meta_keywords'		=>	$seo_meta_keywords
					)
				);
			}
		}
	}
}

$sql = "
		SELECT
			z.*
		FROM
			(
				SELECT
					gm.type_id,
					t.filter_name,
					t.seo_path as 'type_seo_path',
					v.id as value_id,
					v.seo_path as 'value_seo_path',
					v.value_name,
					t1.filter_name as top_level_filter_name,
					v1.id as top_level_filter_value_id,
					fg.cat_id as 'top_level_filter_cat_id',
					t1.seo_path as 'top_level_type_seo_path',
					v1.seo_path as 'top_level_value_seo_path',
					v1.value_name as 'top_level_value_name',
					t.seo_meta_title as 'type_seo_meta_title',
					t.seo_meta_description as 'type_seo_meta_description',
					t.seo_meta_keywords as 'type_seo_meta_keywords',
					v.seo_meta_title as 'value_seo_meta_title',
					v.seo_meta_description as 'value_seo_meta_description',
					v.seo_meta_keywords as 'value_seo_meta_keywords',
					t1.seo_meta_title as 'top_level_type_seo_meta_title',
					t1.seo_meta_description as 'top_level_type_seo_meta_description',
					t1.seo_meta_keywords as 'top_level_type_seo_meta_keywords',
					v1.seo_meta_title as 'top_level_value_seo_meta_title',
					v1.seo_meta_description as 'top_level_value_seo_meta_description',
					v1.seo_meta_keywords as 'top_level_value_seo_meta_keywords'
				FROM
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_group fg

				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_values v1
						ON
							fg.linked_value_id = v1.id
							AND
							fg.linked_value_id > 0
							AND
							v1.enabled = 1
				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_type t1
						ON
							v1.type_id = t1.id
							AND
							t1.enabled = 1
				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_group_memberships gm
						ON
							fg.id = gm.group_id
							AND
							gm.enabled = 1
				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_type t
						ON
							gm.type_id = t.id
							AND
							t.enabled = 1
				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_values v
						ON
							t.id = v.type_id
							AND
							v.enabled = 1
				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_assign a
						ON
							v.id = a.value_id
							AND
							a.enabled = 1
				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_category_index ccci1
						ON
							a.product_id = ccci1.product_id
							AND
							ccci1.cat_id = fg.cat_id
				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_category cag
						ON
							ccci1.cat_id = cag.cat_id
							AND
							cag.status = 1
				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_inventory ii1
						ON
							ccci1.product_id = ii1.product_id
							AND
							ii1.status = 1
				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_assign faa1
						ON
							a.product_id = faa1.product_id
							AND
							faa1.enabled = 1
							AND
							faa1.value_id = v1.id
				WHERE
					fg.enabled = 1
				GROUP BY
					fg.id,
					fg.group_name,
					gm.type_id,
					t.filter_name,
					v.id ,
					v.value_name,
					t1.filter_name,
					v1.id
			UNION ALL
				SELECT
					gm.type_id,
					t.filter_name,
					t.seo_path as 'type_seo_path',
					v.id as value_id,
					v.seo_path as 'value_seo_path',
					v.value_name,
					t1.filter_name as top_level_filter_name,
					v1.id as top_level_filter_value_id,
					fg.cat_id as 'top_level_filter_cat_id',
					t1.seo_path as 'top_level_type_seo_path',
					v1.seo_path as 'top_level_value_seo_path',
					v1.value_name as 'top_level_value_name',
					t.seo_meta_title as 'type_seo_meta_title',
					t.seo_meta_description as 'type_seo_meta_description',
					t.seo_meta_keywords as 'type_seo_meta_keywords',
					v.seo_meta_title as 'value_seo_meta_title',
					v.seo_meta_description as 'value_seo_meta_description',
					v.seo_meta_keywords as 'value_seo_meta_keywords',
					t1.seo_meta_title as 'top_level_type_seo_meta_title',
					t1.seo_meta_description as 'top_level_type_seo_meta_description',
					t1.seo_meta_keywords as 'top_level_type_seo_meta_keywords',
					v1.seo_meta_title as 'top_level_value_seo_meta_title',
					v1.seo_meta_description as 'top_level_value_seo_meta_description',
					v1.seo_meta_keywords as 'top_level_value_seo_meta_keywords'
				FROM
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_group fg

				LEFT JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_values v1
						ON
							fg.linked_value_id = v1.id
							AND
							fg.linked_value_id > 0
							AND
							v1.enabled = 1
				LEFT JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_type t1
						ON
							v1.type_id = t1.id
							AND
							t1.enabled = 1

				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_group_memberships gm
						ON
							fg.id = gm.group_id
							AND
							gm.enabled = 1
				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_type t
						ON
							gm.type_id = t.id
							AND
							t.enabled = 1
				JOIN
					" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_values v
						ON
							t.id = v.type_id
							AND
							v.enabled = 1
				JOIN
					(
						SELECT
							value_id,
							count(value_id) as assigned_total
						FROM
							" . $GLOBALS['config']->get('config', 'dbprefix') . "CubeCart_product_filter_assign
						WHERE
							enabled = 1
						GROUP BY
							value_id
					) a
						ON
							v.id = a.value_id
				WHERE
					fg.enabled = 1
					and
					fg.linked_value_id = 0

			) z
	";
$query = $GLOBALS['db']->query($sql);

if(isset($query) && is_array($query) && !empty($query)){
	foreach($query as $found_filter){

		$cat_seo_path = $GLOBALS['seo']->getdbPath('cat', $found_filter['top_level_filter_cat_id']);
		$custom_filter_list_items_1 = "<li><b>" . $found_filter['top_level_filter_name'] . "</b> : " . $found_filter['top_level_value_name'] . "</li>";
		$custom_filter_list_items_2 = "<li><b>" . $found_filter['top_level_filter_name'] . "</b> : " . $found_filter['top_level_value_name'] . "</li><li><b>" . $found_filter['filter_name'] . "</b> : " . $found_filter['value_name'] . "</li>";

		// What is our array?
		$this_filter_level_1 = array(
			$found_filter['top_level_filter_name'] => array(
				$found_filter['top_level_filter_value_id']
			)
		);
		$this_filter_level_2 = array(
			$found_filter['top_level_filter_name'] => array(
				$found_filter['top_level_filter_value_id']
			),
			$found_filter['filter_name'] => array(
				$found_filter['value_id']
			)
		);

		// Ensure our array is standard
		// Sort array by keys first....
		ksort($this_filter_level_1);
		ksort($this_filter_level_2);

		// Then for each child array, sort by value
		foreach($this_filter_level_1 as $key => $val){
			asort($val);
			// Remove the original key & values
			unset($this_filter_level_1[$key]);
			// Then replace them with the newly sorted array
			$this_filter_level_1[$key] = $val;
		}

		foreach($this_filter_level_2 as $key => $val){
			asort($val);
			// Remove the original key & values
			unset($this_filter_level_2[$key]);
			// Then replace them with the newly sorted array
			$this_filter_level_2[$key] = $val;
		}

		$serialized_level_1 = serialize($this_filter_level_1);
		$hash_level_1 = md5($found_filter['top_level_filter_cat_id'] . $serialized_level_1);
		$complete_array_level_1 = serialize(array(
			'filter_conditions'	=>	$this_filter_level_1
		));

		$serialized_level_2 = serialize($this_filter_level_2);
		$hash_level_2 = md5($found_filter['top_level_filter_cat_id'] . $serialized_level_2);
		$complete_array_level_2 = serialize(array(
			'filter_conditions'	=>	$this_filter_level_2
		));

		// Build our new path
		$raw_path_level_1 = $cat_seo_path . " " . $found_filter['top_level_type_seo_path'] . " " . $found_filter['top_level_value_seo_path'];
		$path_level_1 = filter_module_safe_url($raw_path_level_1);
		$url_level_1 = $path_level_1.$GLOBALS['seo']->getExtension();

		$raw_path_level_2 = $cat_seo_path . " " . $found_filter['top_level_type_seo_path'] . " " . $found_filter['top_level_value_seo_path'] . " " . $found_filter['type_seo_path'] . " " . $found_filter['value_seo_path'];
		$path_level_2 = filter_module_safe_url($raw_path_level_2);
		$url_level_2 = $path_level_2.$GLOBALS['seo']->getExtension();

		$seo_meta_title_1 = $found_filter['top_level_type_seo_meta_title'] . " " . $found_filter['top_level_value_seo_meta_title'];
		$seo_meta_description_1 = $found_filter['top_level_type_seo_meta_description'] . " " . $found_filter['top_level_value_seo_meta_description'];
		$seo_meta_keywords_1 = $found_filter['top_level_type_seo_meta_keywords'] . " " . $found_filter['top_level_value_seo_meta_keywords'];

		$seo_meta_title_2 = $found_filter['top_level_type_seo_meta_title'] . " " . $found_filter['top_level_value_seo_meta_title'] . " " . $found_filter['type_seo_meta_title'] . " " . $found_filter['value_seo_meta_title'];
		$seo_meta_description_2 = $found_filter['top_level_type_seo_meta_description'] . " " . $found_filter['top_level_value_seo_meta_description'] . " " . $found_filter['type_seo_meta_description'] . " " . $found_filter['value_seo_meta_description'];
		$seo_meta_keywords_2 = $found_filter['top_level_type_seo_meta_keywords'] . " " . $found_filter['top_level_value_seo_meta_keywords'] . " " . $found_filter['type_seo_meta_keywords'] . " " . $found_filter['value_seo_meta_keywords'];

		// Add top level, only if it doesn't already exist.
		$lvl1_check = $GLOBALS['db']->select('CubeCart_seo_urls', false, array('custom_filter_hash' => $hash_level_1), false, false, false, false);
		if(isset($lvl1_check) && empty($lvl1_check)){
			$GLOBALS['db']->insert('CubeCart_seo_urls',
				array(
					'path'									=>	$path_level_1,
					'type'									=>	'cat',
					'item_id'								=>	$found_filter['top_level_filter_cat_id'],
					'custom'								=>	1,
					'custom_filter_parameters'				=>	$complete_array_level_1,
					'custom_filter_hash'					=>	$hash_level_1,
					'custom_filter_url'						=>	$url_level_1,
					'custom_filter_record'					=> 	1,
					'custom_filter_list_items'				=> $custom_filter_list_items_1,
					'custom_filter_seo_meta_title'			=>	$seo_meta_title_1,
					'custom_filter_seo_meta_description'	=>	$seo_meta_description_1,
					'custom_filter_seo_meta_keywords'		=>	$seo_meta_keywords_1
				)
			);
		}

		$GLOBALS['db']->insert('CubeCart_seo_urls',
			array(
				'path'									=>	$path_level_2,
				'type'									=>	'cat',
				'item_id'								=>	$found_filter['top_level_filter_cat_id'],
				'custom'								=>	1,
				'custom_filter_parameters'				=>	$complete_array_level_2,
				'custom_filter_hash'					=>	$hash_level_2,
				'custom_filter_url'						=>	$url_level_2,
				'custom_filter_record'					=> 	1,
				'custom_filter_list_items'				=>  $custom_filter_list_items_2,
				'custom_filter_seo_meta_title'			=>	$seo_meta_title_2,
				'custom_filter_seo_meta_description'	=>	$seo_meta_description_2,
				'custom_filter_seo_meta_keywords'		=>	$seo_meta_keywords_2
			)
		);
	}
}

?>